Class: Google::Apis::FitnessV1::ListSessionsResponse

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/fitness_v1/classes.rb,
lib/google/apis/fitness_v1/representations.rb,
lib/google/apis/fitness_v1/representations.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ ListSessionsResponse

Returns a new instance of ListSessionsResponse.



808
809
810
# File 'lib/google/apis/fitness_v1/classes.rb', line 808

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#deleted_sessionArray<Google::Apis::FitnessV1::Session>

If includeDeleted is set to true in the request, and startTime and endTime are omitted, this will include sessions which were deleted since the last sync. Corresponds to the JSON property deletedSession



787
788
789
# File 'lib/google/apis/fitness_v1/classes.rb', line 787

def deleted_session
  @deleted_session
end

#has_more_dataBoolean Also known as: has_more_data?

Flag to indicate server has more data to transfer. DO NOT USE THIS FIELD. It is never populated in responses from the server. Corresponds to the JSON property hasMoreData

Returns:

  • (Boolean)


793
794
795
# File 'lib/google/apis/fitness_v1/classes.rb', line 793

def has_more_data
  @has_more_data
end

#next_page_tokenString

The sync token which is used to sync further changes. This will only be provided if both startTime and endTime are omitted from the request. Corresponds to the JSON property nextPageToken

Returns:

  • (String)


800
801
802
# File 'lib/google/apis/fitness_v1/classes.rb', line 800

def next_page_token
  @next_page_token
end

#sessionArray<Google::Apis::FitnessV1::Session>

Sessions starting before endTime of the request and ending after startTime of the request up to (endTime of the request + 1 day). Corresponds to the JSON property session



806
807
808
# File 'lib/google/apis/fitness_v1/classes.rb', line 806

def session
  @session
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



813
814
815
816
817
818
# File 'lib/google/apis/fitness_v1/classes.rb', line 813

def update!(**args)
  @deleted_session = args[:deleted_session] if args.key?(:deleted_session)
  @has_more_data = args[:has_more_data] if args.key?(:has_more_data)
  @next_page_token = args[:next_page_token] if args.key?(:next_page_token)
  @session = args[:session] if args.key?(:session)
end