Class: Google::Apis::FitnessV1::Session

Inherits:
Object
  • Object
show all
Includes:
Core::Hashable, Core::JsonObjectSupport
Defined in:
lib/google/apis/fitness_v1/classes.rb,
lib/google/apis/fitness_v1/representations.rb,
lib/google/apis/fitness_v1/representations.rb

Overview

Sessions contain metadata, such as a user-friendly name and time interval information.

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(**args) ⇒ Session

Returns a new instance of Session.



896
897
898
# File 'lib/google/apis/fitness_v1/classes.rb', line 896

def initialize(**args)
   update!(**args)
end

Instance Attribute Details

#active_time_millisFixnum

Session active time. While start_time_millis and end_time_millis define the full session time, the active time can be shorter and specified by active_time_millis. If the inactive time during the session is known, it should also be inserted via a com.google.activity.segment data point with a STILL activity value Corresponds to the JSON property activeTimeMillis

Returns:

  • (Fixnum)


853
854
855
# File 'lib/google/apis/fitness_v1/classes.rb', line 853

def active_time_millis
  @active_time_millis
end

#activity_typeFixnum

The type of activity this session represents. Corresponds to the JSON property activityType

Returns:

  • (Fixnum)


858
859
860
# File 'lib/google/apis/fitness_v1/classes.rb', line 858

def activity_type
  @activity_type
end

#applicationGoogle::Apis::FitnessV1::Application

The application that created the session. Corresponds to the JSON property application



863
864
865
# File 'lib/google/apis/fitness_v1/classes.rb', line 863

def application
  @application
end

#descriptionString

A description for this session. Corresponds to the JSON property description

Returns:

  • (String)


868
869
870
# File 'lib/google/apis/fitness_v1/classes.rb', line 868

def description
  @description
end

#end_time_millisFixnum

An end time, in milliseconds since epoch, inclusive. Corresponds to the JSON property endTimeMillis

Returns:

  • (Fixnum)


873
874
875
# File 'lib/google/apis/fitness_v1/classes.rb', line 873

def end_time_millis
  @end_time_millis
end

#idString

A client-generated identifier that is unique across all sessions owned by this particular user. Corresponds to the JSON property id

Returns:

  • (String)


879
880
881
# File 'lib/google/apis/fitness_v1/classes.rb', line 879

def id
  @id
end

#modified_time_millisFixnum

A timestamp that indicates when the session was last modified. Corresponds to the JSON property modifiedTimeMillis

Returns:

  • (Fixnum)


884
885
886
# File 'lib/google/apis/fitness_v1/classes.rb', line 884

def modified_time_millis
  @modified_time_millis
end

#nameString

A human readable name of the session. Corresponds to the JSON property name

Returns:

  • (String)


889
890
891
# File 'lib/google/apis/fitness_v1/classes.rb', line 889

def name
  @name
end

#start_time_millisFixnum

A start time, in milliseconds since epoch, inclusive. Corresponds to the JSON property startTimeMillis

Returns:

  • (Fixnum)


894
895
896
# File 'lib/google/apis/fitness_v1/classes.rb', line 894

def start_time_millis
  @start_time_millis
end

Instance Method Details

#update!(**args) ⇒ Object

Update properties of this object



901
902
903
904
905
906
907
908
909
910
911
# File 'lib/google/apis/fitness_v1/classes.rb', line 901

def update!(**args)
  @active_time_millis = args[:active_time_millis] if args.key?(:active_time_millis)
  @activity_type = args[:activity_type] if args.key?(:activity_type)
  @application = args[:application] if args.key?(:application)
  @description = args[:description] if args.key?(:description)
  @end_time_millis = args[:end_time_millis] if args.key?(:end_time_millis)
  @id = args[:id] if args.key?(:id)
  @modified_time_millis = args[:modified_time_millis] if args.key?(:modified_time_millis)
  @name = args[:name] if args.key?(:name)
  @start_time_millis = args[:start_time_millis] if args.key?(:start_time_millis)
end